import React from 'react';
import { ColorToken, PropsWithMetadata } from '@highlight-ui/utils-commons';
import { IconProps } from '@highlight-ui/icon';
import { BodyProps } from '@highlight-ui/typography';
import { BaseButtonState } from './types';
export declare type BaseButtonStateProps = {
    color: NonNullable<BodyProps['color']> | ColorToken;
    backgroundColor: ColorToken | null;
};
export declare type BaseButtonLoadingStateProps = {
    color: NonNullable<IconProps['color']>;
};
export declare type BaseButtonRef = React.Ref<HTMLButtonElement>;
export declare type BaseButtonProps = React.PropsWithChildren<PropsWithMetadata<{
    /** Makes the component behave as a block element (take up the whole available space) */
    block?: boolean;
    /** Determines the state of the button */
    buttonState?: BaseButtonState;
    /** The icon to be placed beside the label */
    icon?: string;
    /** The default button state */
    _default: BaseButtonStateProps;
    /** The button hover state */
    _hover: BaseButtonStateProps;
    /** The button active state */
    _active: BaseButtonStateProps;
    /** The button active state */
    _disabled: BaseButtonStateProps;
    /** The button loading state */
    _loading: BaseButtonLoadingStateProps;
}>> & Omit<React.ComponentPropsWithoutRef<'button'>, 'disabled'>;
declare const BaseButton: React.ForwardRefExoticComponent<{
    /** Makes the component behave as a block element (take up the whole available space) */
    block?: boolean | undefined;
    /** Determines the state of the button */
    buttonState?: BaseButtonState | undefined;
    /** The icon to be placed beside the label */
    icon?: string | undefined;
    /** The default button state */
    _default: BaseButtonStateProps;
    /** The button hover state */
    _hover: BaseButtonStateProps;
    /** The button active state */
    _active: BaseButtonStateProps;
    /** The button active state */
    _disabled: BaseButtonStateProps;
    /** The button loading state */
    _loading: BaseButtonLoadingStateProps;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & Omit<Pick<React.DetailedHTMLProps<React.ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement>, "key" | keyof React.ButtonHTMLAttributes<HTMLButtonElement>>, "disabled"> & React.RefAttributes<HTMLButtonElement>>;
export default BaseButton;
